from awsreport.core.log import Logging

class Banner(Logging):
    def display_banner(self):
        self.print_green(
'''

 █████╗ ██╗    ██╗███████╗    ██████╗ ███████╗██████╗  ██████╗ ██████╗ ████████╗
██╔══██╗██║    ██║██╔════╝    ██╔══██╗██╔════╝██╔══██╗██╔═══██╗██╔══██╗╚══██╔══╝
███████║██║ █╗ ██║███████╗    ██████╔╝█████╗  ██████╔╝██║   ██║██████╔╝   ██║
██╔══██║██║███╗██║╚════██║    ██╔══██╗██╔══╝  ██╔═══╝ ██║   ██║██╔══██╗   ██║
██║  ██║╚███╔███╔╝███████║    ██║  ██║███████╗██║     ╚██████╔╝██║  ██║   ██║
╚═╝  ╚═╝ ╚══╝╚══╝ ╚══════╝    ╚═╝  ╚═╝╚══════╝╚═╝      ╚═════╝ ╚═╝  ╚═╝   ╚═╝

AWS Report is a tool for analyzing amazon resources.

''')

        print("-" * 79)
